@@ -1,4 +1,3 @@
-# coding: utf-8
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -442,18 +441,27 @@ def test_parse_hostspec(hostspec, expected):
     assert BaseBackend.parse_hostspec(hostspec) == expected
 
 
-@pytest.mark.parametrize('hostspec,pod,container,namespace,kubeconfig', [
-    ('kubectl://pod', 'pod', None, None, None),
-    ('kubectl://pod?namespace=n', 'pod', None, 'n', None),
-    ('kubectl://pod?container=c&namespace=n', 'pod', 'c', 'n', None),
-    ('kubectl://pod?namespace=n&kubeconfig=k', 'pod', None, 'n', 'k')
-])
-def test_kubectl_hostspec(hostspec, pod, container, namespace, kubeconfig):
+@pytest.mark.parametrize(
+    'hostspec,pod,container,namespace,kubeconfig,context', [
+        ('kubectl://pod', 'pod', None, None, None, None),
+        ('kubectl://pod?namespace=n', 'pod', None, 'n', None, None),
+        ('kubectl://pod?container=c&namespace=n',
+         'pod', 'c', 'n', None, None),
+        ('kubectl://pod?namespace=n&kubeconfig=k',
+         'pod', None, 'n', 'k', None),
+        ('kubectl://pod?context=ctx&container=c',
+         'pod', 'c', None, None, 'ctx')
+    ]
+)
+def test_kubectl_hostspec(
+    hostspec, pod, container, namespace, kubeconfig, context,
+):
     backend = testinfra.get_host(hostspec).backend
     assert backend.name == pod
     assert backend.container == container
     assert backend.namespace == namespace
     assert backend.kubeconfig == kubeconfig
+    assert backend.context == context
 
 
 @pytest.mark.parametrize('hostspec,pod,container,namespace,kubeconfig', [
